@@ -6,7 +6,7 @@ from http.cookiejar import CookieJar as cj
 from Downloader import ArticleDownloader
 from FList import LIST
 
-import Resources
+import FairResources
 from FExt import EXT
 from FLog.LOGGER import Log
 Log = Log("FWEB.Core.HttpRequest")
@@ -24,20 +24,19 @@ HEADERS = {
     "referer": "https://www.google.com/",
 }
 HEADERS_EXT = {
-    "scheme": "https",
-    "path": "/public/event/2038/individual-team/18/11332/9",
-    "method": "GET",
+    ":authority": "sec.report",
+    ":scheme": "https",
+    ":method": "GET",
+    ":path": "/CIK/Search/Lockheed+Martin+Corporation+Common+Stock",
     "user-agent": "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/99.0.4844.51 Safari/537.36",
     "accept-language": "en-US,en;q=0.9",
     "accept-encoding": "gzip, deflate, br",
     "content-type": "text/html",
-    "accept": "text/html,application/xhtml+xml,application/xml;q=0.9,image/avif,image/webp,image/apng,*/*;q=0.8,application/signed-exchange;v=b3;q=0.9",
-    "referer": "https://www.birminghamunited.com/",
-    "sec-fetch-mode": "navigate",
-    "sec-fetch-dest": "document",
-    "sec-fetch-site": "cross-site",
-    "sec-fetch-user": "?1",
-    "sec-ch-ua-mobile": "?0",
+    "accept": "application/signed-exchange;v=b3;q=0.7,*/*;q=0.8",
+    "referer": "https://sec.report/Senate-Stock-Disclosures",
+    "sec-fetch-mode": "no-cors",
+    "sec-fetch-dest": "empty",
+    "sec-fetch-site": "same-origin",
     "sec-ch-ua-platform": "macOS",
     "upgrade-insecure-requests": "1",
     "sec-ch-ua": "'Not A;Brand';v='99', 'Chromium';v='99', 'Google Chrome';v='99'"
@@ -52,10 +51,10 @@ PROXIES = {
 
 # -> Step One -> Call URL and get Raw HTML back in Response Object.
 # @Ext.safe_run
-@EXT.sleep(5)
+@EXT.sleep(1)
 def get_request(url):
     try:
-        HEADERS["user-agent"] = Resources.get_random_user_agent()
+        HEADERS["user-agent"] = FairResources.get_random_user_agent()
         Log.i("Making HTTP Request.", v=f"URL= [ {url} ] ")
         response = requests.get(url, headers=HEADERS, timeout=10)
         if response.status_code > 205:
@@ -83,10 +82,10 @@ def get_request_3k_to_html(url, parseToSoup=True):
         Log.e(f"Failed to get HTML from URL=[ {url} ]", error=e)
         return False
 
-@EXT.sleep(5)
+@EXT.sleep(1)
 def get_request_v2(url):
     try:
-        HEADERS["user-agent"] = Resources.get_random_user_agent()
+        HEADERS["user-agent"] = FairResources.get_random_user_agent()
         Log.i("Making HTTP Request.", v=f"URL= [ {url} ] ")
         response = requests.get(url, **get_request_kwargs())
         if response.status_code > 205:
@@ -143,7 +142,7 @@ def get_request_kwargs():
     """This Wrapper method exists b/c some values in req_kwargs dict
     are methods which need to be called every time we make a request
     """
-    HEADERS["user-agent"] = Resources.get_random_user_agent()
+    HEADERS["user-agent"] = FairResources.get_random_user_agent()
     timeout = 7
     proxies = {}
     return {
@@ -155,11 +154,21 @@ def get_request_kwargs():
     }
 
 if __name__ == '__main__':
+    from Soup import BeautifulSoup
+    from bs4.dammit import EncodingDetector
     url1 = "https://cointelegraph.com/news/price-analysis-1-28-btc-eth-bnb-ada-sol-xrp-luna-doge-dot-avax"
     date_none = "https://finance.yahoo.com/news/metaverse-real-estate-market-growing-115600231.html"
-    test = get_request_v2(date_none)
-    res = LIST.get(1, test)
-    resp = res.text
+    tableUrl = "https://www.quiverquant.com/dashboard/NVDA/"
+    table2 = "https://sec.report/Senate-Stock-Disclosures"
+    test = get_request_v2(table2)
+    test2 = get_request(table2)
+    resp = LIST.get(1, test)
+    resp2 = LIST.get(1, test2)
+    http_encoding = resp.encoding if 'charset' in resp.headers.get('content-type', '').lower() else None
+    html_encoding = EncodingDetector.find_declared_encoding(resp.content, is_html=True)
+    encoding = html_encoding or http_encoding
+    testing = BeautifulSoup(resp.text, 'lxml', from_encoding=encoding)
+    resp = str(resp.text)
     print(resp)
     arttt = ArticleDownloader.parse_html(date_none, resp)
     print(arttt)
\ No newline at end of file
